@@ -50,8 +50,8 @@ def get_enabled_cfg_apps() -> List[str]:
     if base_module.is_payments_enabled():
         enabled_apps.append("django_cfg.apps.payments")
 
-    if base_module.is_rpc_enabled():
-        enabled_apps.append("django_cfg.apps.ipc")
+    if base_module.is_centrifugo_enabled():
+        enabled_apps.append("django_cfg.apps.centrifugo")
 
     return enabled_apps
 
@@ -166,9 +166,9 @@ APP_URL_MAP = {
         ("cfg/payments/", "django_cfg.apps.payments.urls"),
         # Payments v2.0: No separate urls_admin (uses Django Admin only)
     ],
-    "django_cfg.apps.ipc": [
-        ("cfg/ipc/", "django_cfg.apps.ipc.urls"),
-        ("cfg/ipc/admin/", "django_cfg.apps.ipc.urls_admin"),
+    "django_cfg.apps.centrifugo": [
+        ("cfg/centrifugo/", "django_cfg.apps.centrifugo.urls"),
+        ("cfg/centrifugo/admin/", "django_cfg.apps.centrifugo.urls_admin"),
     ],
 }
 
