@@ -15,11 +15,12 @@ from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel, Field, PrivateAttr, field_validator, model_validator
 
-from ...apps.ipc import DjangoCfgRPCConfig
+from ...apps.centrifugo.services.client.config import DjangoCfgCentrifugoConfig
 from ...models import (
     ApiKeys,
     AxesConfig,
     CacheConfig,
+    CryptoFieldsConfig,
     DatabaseConfig,
     DRFConfig,
     EmailConfig,
@@ -165,16 +166,6 @@ class DjangoConfig(BaseModel):
         description="Backend API URL",
     )
 
-    ticket_url: str = Field(
-        default="{site_url}/support/ticket/{uuid}",
-        description="Support ticket URL template. Use {site_url} and {uuid} placeholders",
-    )
-
-    otp_url: str = Field(
-        default="{site_url}/auth/otp/{code}",
-        description="OTP verification URL template. Use {site_url} and {code} placeholders",
-    )
-
     # === Core Django Settings ===
     secret_key: str = Field(
         ...,
@@ -284,6 +275,11 @@ class DjangoConfig(BaseModel):
         description="Django-Axes brute-force protection configuration (None = smart defaults)",
     )
 
+    crypto_fields: Optional["CryptoFieldsConfig"] = Field(
+        default=None,
+        description="Django Crypto Fields encryption configuration for sensitive data (API keys, tokens, passwords)",
+    )
+
     # === Admin Interface Configuration ===
     unfold: Optional[UnfoldConfig] = Field(
         default=None,
@@ -316,10 +312,10 @@ class DjangoConfig(BaseModel):
         description="Background task processing configuration (Dramatiq)",
     )
 
-    # === RPC Client Configuration ===
-    django_ipc: Optional[DjangoCfgRPCConfig] = Field(
+    # === Centrifugo Configuration ===
+    centrifugo: Optional[DjangoCfgCentrifugoConfig] = Field(
         default=None,
-        description="Django-CFG RPC Client configuration (WebSocket RPC communication)",
+        description="Centrifugo pub/sub configuration (WebSocket notifications with ACK tracking)",
     )
 
     # === API Configuration ===
@@ -568,36 +564,6 @@ class DjangoConfig(BaseModel):
 
         return self._django_settings
 
-    def get_ticket_url(self, ticket_uuid: str) -> str:
-        """
-        Generate ticket URL using the configured template.
-
-        Args:
-            ticket_uuid: UUID of the support ticket
-
-        Returns:
-            Complete URL to the ticket
-        """
-        return self.ticket_url.format(
-            site_url=self.site_url,
-            uuid=ticket_uuid,
-        )
-
-    def get_otp_url(self, otp_code: str) -> str:
-        """
-        Generate OTP verification URL using the configured template.
-
-        Args:
-            otp_code: OTP verification code
-
-        Returns:
-            Complete URL to the OTP verification page
-        """
-        return self.otp_url.format(
-            site_url=self.site_url,
-            code=otp_code,
-        )
-
     def invalidate_cache(self) -> None:
         """
         Invalidate cached Django settings.
