@@ -133,8 +133,11 @@ class InstalledAppsBuilder:
         if self.config.payments and self.config.payments.enabled:
             apps.append("django_cfg.apps.payments")
 
-        if self.config.django_ipc and self.config.django_ipc.enabled:
-            apps.append("django_cfg.apps.ipc")
+        if self.config.centrifugo and self.config.centrifugo.enabled:
+            apps.append("django_cfg.apps.centrifugo")
+
+        if self.config.crypto_fields and self.config.crypto_fields.enabled:
+            apps.append("django_crypto_fields.apps.AppConfig")
 
         return apps
 
