@@ -34,6 +34,7 @@ from .base.module import BaseCfgAutoModule
 # Django-specific
 from .django.axes import AxesConfig
 from .django.constance import ConstanceConfig, ConstanceField
+from .django.crypto_fields import CryptoFieldsConfig
 from .django.environment import EnvironmentConfig
 from .django.openapi import OpenAPIClientConfig
 from .infrastructure.cache import CacheConfig
@@ -81,6 +82,7 @@ __all__ = [
     "OpenAPIClientConfig",
     "UnfoldConfig",
     "AxesConfig",
+    "CryptoFieldsConfig",
     # Services
     "EmailConfig",
     "TelegramConfig",
