@@ -2,7 +2,8 @@
 Ngrok tunnel configuration.
 """
 
-from typing import Optional, List, Literal
+from typing import List, Literal, Optional
+
 from pydantic import BaseModel, Field
 
 
