@@ -14,7 +14,7 @@ from django.core.management.base import BaseCommand, CommandError
 class Command(BaseCommand):
     """Generate OpenAPI clients for configured application groups."""
 
-    help = "Generate Python and TypeScript API clients from OpenAPI schemas"
+    help = "Generate Python, TypeScript, and Go API clients from OpenAPI schemas"
 
     def add_arguments(self, parser):
         """Add command arguments."""
@@ -37,6 +37,12 @@ class Command(BaseCommand):
             help="Generate TypeScript client only",
         )
 
+        parser.add_argument(
+            "--go",
+            action="store_true",
+            help="Generate Go client only",
+        )
+
         parser.add_argument(
             "--no-python",
             action="store_true",
@@ -49,6 +55,12 @@ class Command(BaseCommand):
             help="Skip TypeScript client generation",
         )
 
+        parser.add_argument(
+            "--no-go",
+            action="store_true",
+            help="Skip Go client generation",
+        )
+
         # Utility options
         parser.add_argument(
             "--dry-run",
@@ -193,15 +205,22 @@ class Command(BaseCommand):
     def _generate_clients(self, service, options):
         """Generate clients."""
         # Determine languages
-        if options["python"] and not options["typescript"]:
+        if options["python"] and not options["typescript"] and not options["go"]:
             python = True
             typescript = False
-        elif options["typescript"] and not options["python"]:
+            go = False
+        elif options["typescript"] and not options["python"] and not options["go"]:
             python = False
             typescript = True
+            go = False
+        elif options["go"] and not options["python"] and not options["typescript"]:
+            python = False
+            typescript = False
+            go = True
         else:
             python = not options["no_python"]
             typescript = not options["no_typescript"]
+            go = not options["no_go"]
 
         # Get groups
         groups = options.get("groups")
@@ -233,6 +252,8 @@ class Command(BaseCommand):
             self.stdout.write("  → Python")
         if typescript:
             self.stdout.write("  → TypeScript")
+        if go:
+            self.stdout.write("  → Go")
 
         if dry_run:
             self.stdout.write(self.style.WARNING("\n✅ Dry run completed - no files generated"))
@@ -248,6 +269,7 @@ class Command(BaseCommand):
 
         from django_cfg.modules.django_client.core import (
             ArchiveManager,
+            GoGenerator,
             GroupManager,
             PythonGenerator,
             TypeScriptGenerator,
@@ -395,6 +417,33 @@ class Command(BaseCommand):
 
                     self.stdout.write(f"  ✅ TypeScript client: {ts_dir} ({len(ts_files)} files)")
 
+                # Generate Go client
+                if go:
+                    self.stdout.write("  → Generating Go client...")
+                    go_dir = service.config.get_group_go_dir(group_name)
+                    go_dir.mkdir(parents=True, exist_ok=True)
+
+                    go_generator = GoGenerator(
+                        ir_context,
+                        client_structure=service.config.client_structure,
+                        openapi_schema=schema_dict,
+                        tag_prefix=f"{group_name}_",
+                        generate_package_files=service.config.generate_package_files,
+                        package_config={
+                            "name": group_name,
+                            "module_name": group_name,
+                            "version": "v1.0.0",
+                        },
+                    )
+                    go_files = go_generator.generate()
+
+                    for generated_file in go_files:
+                        full_path = go_dir / generated_file.path
+                        full_path.parent.mkdir(parents=True, exist_ok=True)
+                        full_path.write_text(generated_file.content)
+
+                    self.stdout.write(f"  ✅ Go client: {go_dir} ({len(go_files)} files)")
+
                 # Archive if enabled
                 if service.config.enable_archive:
                     self.stdout.write("  → Archiving...")
@@ -428,3 +477,5 @@ class Command(BaseCommand):
             self.stdout.write(f"  Python:     {service.config.get_python_clients_dir()}")
         if typescript:
             self.stdout.write(f"  TypeScript: {service.config.get_typescript_clients_dir()}")
+        if go:
+            self.stdout.write(f"  Go:         {service.config.get_go_clients_dir()}")
