@@ -19,6 +19,7 @@ from django_cfg.modules.django_dashboard.sections.documentation import Documenta
 from django_cfg.modules.django_dashboard.sections.overview import OverviewSection
 from django_cfg.modules.django_dashboard.sections.stats import StatsSection
 from django_cfg.modules.django_dashboard.sections.system import SystemSection
+from django_cfg.modules.django_dashboard.sections.widgets import WidgetsSection
 
 from ...base import BaseCfgModule
 from ..models.dashboard import DashboardData
@@ -155,6 +156,29 @@ class UnfoldCallbacks(
                 logger.error(f"Failed to render documentation section: {e}", exc_info=True)
                 documentation_section = None
 
+            # Extract custom widgets from context if provided by project's dashboard_callback
+            custom_widgets = context.get('custom_widgets', [])
+            custom_metrics = {}
+
+            # Extract all metric-like variables from context for widget template resolution
+            # This allows dashboard_callback to add metrics like: context['total_users'] = 123
+            for key, value in context.items():
+                if key not in ['request', 'cards', 'system_health', 'quick_actions'] and isinstance(value, (int, float, str)):
+                    custom_metrics[key] = value
+
+            try:
+                # Render widgets section with custom widgets and metrics from callback
+                widgets_section = WidgetsSection(request).render(
+                    custom_widgets=custom_widgets,
+                    custom_metrics=custom_metrics
+                )
+                # Debug: save render (only in debug mode)
+                if config and config.debug:
+                    save_section_render('widgets', widgets_section)
+            except Exception as e:
+                logger.error(f"Failed to render widgets section: {e}", exc_info=True)
+                widgets_section = None
+
             # Combine all stat cards (data already loaded above)
             all_stats = user_stats + support_stats
 
@@ -176,6 +200,7 @@ class UnfoldCallbacks(
                 "system_section": system_section,
                 "commands_section": commands_section,
                 "documentation_section": documentation_section,
+                "widgets_section": widgets_section,
 
                 # Statistics cards
                 "cards": cards_data,
@@ -252,24 +277,24 @@ class UnfoldCallbacks(
             })
 
             # Log charts data for debugging
-            charts_data = context.get('charts', {})
-            logger.info(f"Charts data added to context: {list(charts_data.keys())}")
-            if 'user_registrations' in charts_data:
-                reg_data = charts_data['user_registrations']
-                logger.info(f"Registration chart labels: {reg_data.get('labels', [])}")
-            if 'user_activity' in charts_data:
-                act_data = charts_data['user_activity']
-                logger.info(f"Activity chart labels: {act_data.get('labels', [])}")
+            # charts_data = context.get('charts', {})
+            # # logger.info(f"Charts data added to context: {list(charts_data.keys())}")
+            # if 'user_registrations' in charts_data:
+            #     reg_data = charts_data['user_registrations']
+            #     logger.info(f"Registration chart labels: {reg_data.get('labels', [])}")
+            # if 'user_activity' in charts_data:
+            #     act_data = charts_data['user_activity']
+            #     logger.info(f"Activity chart labels: {act_data.get('labels', [])}")
 
-            # Log recent users data for debugging
-            recent_users_data = context.get('recent_users', [])
-            logger.info(f"Recent users data count: {len(recent_users_data)}")
-            if recent_users_data:
-                logger.info(f"First user: {recent_users_data[0].get('username', 'N/A')}")
+            # # Log recent users data for debugging
+            # recent_users_data = context.get('recent_users', [])
+            # logger.info(f"Recent users data count: {len(recent_users_data)}")
+            # if recent_users_data:
+            #     logger.info(f"First user: {recent_users_data[0].get('username', 'N/A')}")
 
-            # Log activity tracker data for debugging
-            activity_tracker_data = context.get('activity_tracker', [])
-            logger.info(f"Activity tracker data count: {len(activity_tracker_data)}")
+            # # Log activity tracker data for debugging
+            # activity_tracker_data = context.get('activity_tracker', [])
+            # logger.info(f"Activity tracker data count: {len(activity_tracker_data)}")
 
             return context
 
