@@ -4,6 +4,7 @@ Navigation Models for Unfold Dashboard
 Pydantic models for navigation items and sections.
 """
 
+import logging
 from enum import Enum
 from typing import Callable, List, Optional, Union
 
@@ -11,6 +12,8 @@ from pydantic import BaseModel, ConfigDict, Field, computed_field
 
 from ..utils import auto_resolve_url
 
+logger = logging.getLogger(__name__)
+
 
 class NavigationItemType(str, Enum):
     """Navigation item types."""
@@ -43,7 +46,12 @@ class NavigationItem(BaseModel):
         return self.resolved_link
 
     def to_dict(self) -> dict:
-        """Convert to dictionary for Unfold admin."""
+        """
+        Convert to dictionary for Unfold admin.
+
+        Note: This is used by dashboard.py which uses direct paths.
+        For URL names, resolution happens in UnfoldConfig.get_navigation() callable.
+        """
         return {
             "title": self.title,
             "icon": self.icon,
