@@ -233,7 +233,7 @@ class SmartDefaults:
         """Get Django REST Framework defaults."""
         return {
             'DEFAULT_AUTHENTICATION_CLASSES': [
-                'rest_framework_simplejwt.authentication.JWTAuthentication',
+                'django_cfg.middleware.authentication.JWTAuthenticationWithLastLogin',
                 # SessionAuthentication removed (requires CSRF)
             ],
             'DEFAULT_PERMISSION_CLASSES': [
